==> 0.6.0%2B6.tar.gz: android/src/main/kotlin/com/snowm/scanner/helpers/BeaconScanner.kt <==
package com.snowm.scanner.helpers

import android.content.Context
import android.content.Intent
import android.content.ServiceConnection
import com.snowm.scanner.models.SnowMiBeacon
import org.altbeacon.beacon.*
import java.util.HashMap
import kotlin.collections.ArrayList
import kotlin.math.floor
import kotlin.math.pow

class BeaconScanner(private val context: Context) : BeaconConsumer, RangeNotifier, MonitorNotifier {
    private val onBeaconScannedInterfaces: HashMap<String, OnBeaconScanned> = HashMap()
    private var beaconManager = BeaconManager.getInstanceForApplication(context)

    init {
        beaconManager.beaconParsers.add(BeaconParser().setBeaconLayout("m:2-3=0215,i:4-19,i:20-21,i:22-23,p:24-24"))
        beaconManager.backgroundMode = false
        beaconManager.bind(this)
    }

    override fun unbindService(p0: ServiceConnection?) {
        return
    }

    override fun bindService(p0: Intent?, p1: ServiceConnection?, p2: Int): Boolean {
         return true
    }

    override fun onBeaconServiceConnect() {
        beaconManager.addMonitorNotifier(this)
        beaconManager.addRangeNotifier(this)
    }

    override fun didRangeBeaconsInRegion(p0: MutableCollection<Beacon>?, p1: Region?) {
        val scannedBeacons = ArrayList<SnowMiBeacon>()
        p0!!.forEach {
            val beacon = SnowMiBeacon()
            beacon.rssi = it.rssi
            beacon.distance = getDistance(it.rssi)
            beacon.distance2 = it.distance
            beacon.macAddress = it.bluetoothAddress
            beacon.txPower = it.txPower
            beacon.major = it.id2.toInt()
            beacon.minor = it.id3.toInt()
            beacon.uuid = it.id1.toString().toUpperCase()
            scannedBeacons.add(beacon)
        }
        onBeaconScannedInterfaces[p1?.uniqueId]?.onBeaconRanged(scannedBeacons)
    }

    fun getDistance(rssi: Int): Double {
        val measuredPower = -65
        val environmetalFactor = getEnvironmentalFactor(rssi)
        val core = (measuredPower - rssi) / (10 * environmetalFactor);
        return 10.0.pow(core)
    }

    fun getEnvironmentalFactor(rssi: Int): Double {
        if (rssi < -100) return 2.0
        if (rssi > -35) return 4.0
        val range = (rssi + 100) / 65
        val value = 2.0 + 2 * range
        return floor(value)
    }

    override fun getApplicationContext(): Context {
        return context.applicationContext
    }


    fun setOnBeaconScanner(identifier: String, onBeaconScanned: OnBeaconScanned) {
        onBeaconScannedInterfaces[identifier] = onBeaconScanned
    }

    fun rangeBeacons(identifier: String,backgroundBetweenScanPeriod: Long,backgroundScanPeriod:Long) {
        val region = Region(identifier, null, null, null)
        beaconManager.removeAllRangeNotifiers()
        beaconManager.startRangingBeaconsInRegion(region)
        if (identifier == "background") {
            beaconManager.backgroundBetweenScanPeriod = backgroundBetweenScanPeriod
            beaconManager.backgroundScanPeriod = backgroundScanPeriod
        }

    }

    fun monitorBeacons(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.removeAllMonitorNotifiers()
        beaconManager.startMonitoringBeaconsInRegion(region)
        if (identifier == "background") {
            beaconManager.backgroundBetweenScanPeriod = 10000
            beaconManager.backgroundScanPeriod = 5000
        }
    }


    fun stopRanging(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.stopRangingBeaconsInRegion(region)
    }

    fun stopMonitoring(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.stopMonitoringBeaconsInRegion(region)
    }

    interface OnBeaconScanned {
        fun onBeaconRanged(beacons: ArrayList<SnowMiBeacon>)
        fun didEnterRegion(p0: Region?)
        fun didExitRegion(p0: Region?)
    }

    override fun didDetermineStateForRegion(p0: Int, p1: Region?) {
        println("teee hee")
    }

    override fun didEnterRegion(p0: Region?) {
        onBeaconScannedInterfaces[p0?.uniqueId]?.didExitRegion(p0)
    }

    override fun didExitRegion(p0: Region?) {
        onBeaconScannedInterfaces[p0?.uniqueId]?.didExitRegion(p0)
    }

}

==> 0.7.0%2B6.tar.gz: android/src/main/kotlin/com/snowm/scanner/helpers/BeaconScanner.kt <==
package com.snowm.scanner.helpers

import android.content.Context
import android.content.Intent
import android.content.ServiceConnection
import com.snowm.scanner.models.SnowMiBeacon
import org.altbeacon.beacon.*
import java.util.*
import kotlin.collections.ArrayList
import kotlin.math.floor
import kotlin.math.pow


class BeaconScanner(private val context: Context) : BeaconConsumer, RangeNotifier, MonitorNotifier {
    private val onBeaconScannedInterfaces: HashMap<String, OnBeaconScanned> = HashMap()
    private var beaconManager = BeaconManager.getInstanceForApplication(context)

    init {
        beaconManager.beaconParsers.add(BeaconParser().setBeaconLayout("m:2-3=0215,i:4-19,i:20-21,i:22-23,p:24-24"))
        beaconManager.bind(this)
    }

    override fun onBeaconServiceConnect() {
        beaconManager.addMonitorNotifier(this)
        beaconManager.addRangeNotifier(this)
    }

    override fun didRangeBeaconsInRegion(p0: MutableCollection<Beacon>?, p1: Region?) {
        val scannedBeacons = ArrayList<SnowMiBeacon>()
        p0!!.forEach {
            val beacon = SnowMiBeacon()
            beacon.rssi = it.rssi
            beacon.distance = getDistance(it.rssi)
            beacon.macAddress = it.bluetoothAddress
            beacon.txPower = it.txPower
            beacon.major = it.id2.toInt()
            beacon.minor = it.id3.toInt()
            beacon.uuid = it.id1.toString().toUpperCase()
            scannedBeacons.add(beacon)
        }
        onBeaconScannedInterfaces[p1?.uniqueId]?.onBeaconRanged(scannedBeacons)
    }

    private fun getDistance(rssi: Int): Double {
        val measuredPower = -65
        val environmetalFactor = getEnvironmentalFactor(rssi)
        val core = (measuredPower - rssi) / (10 * environmetalFactor);
        return 10.0.pow(core)
    }

    private fun getEnvironmentalFactor(rssi: Int): Double {
        if (rssi < -100) return 2.0
        if (rssi > -35) return 4.0
        val range = (rssi + 100) / 65
        val value = 2.0 + 2 * range
        return floor(value)
    }

    override fun getApplicationContext(): Context {
        return context.applicationContext
    }

    override fun unbindService(p0: ServiceConnection?) {
        TODO("Not yet implemented")
    }

    override fun bindService(p0: Intent?, p1: ServiceConnection?, p2: Int): Boolean {
        TODO("Not yet implemented")
    }


    fun setOnBeaconScanner(identifier: String, onBeaconScanned: OnBeaconScanned) {
        onBeaconScannedInterfaces[identifier] = onBeaconScanned
    }

    fun rangeBeacons(identifier: String, backgroundBetweenScanPeriod: Long, backgroundScanPeriod: Long) {
        if (identifier == "background") {
             beaconManager.backgroundBetweenScanPeriod = backgroundBetweenScanPeriod
             beaconManager.backgroundScanPeriod = backgroundScanPeriod
        }
        val region = Region(identifier, null, null, null)
        beaconManager.removeAllRangeNotifiers()
        beaconManager.startRangingBeaconsInRegion(region)
        beaconManager.addRangeNotifier(this)

    }

    fun monitorBeacons(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.removeAllMonitorNotifiers()
        beaconManager.startMonitoringBeaconsInRegion(region)
    }


    fun stopRanging(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.stopRangingBeaconsInRegion(region)
    }

    fun stopMonitoring(identifier: String) {
        val region = Region(identifier, null, null, null)
        beaconManager.stopMonitoringBeaconsInRegion(region)
    }

    interface OnBeaconScanned {
        fun onBeaconRanged(beacons: ArrayList<SnowMiBeacon>)
        fun didEnterRegion(p0: Region?)
        fun didExitRegion(p0: Region?)
    }

    override fun didDetermineStateForRegion(p0: Int, p1: Region?) {
        println("teee hee")
    }

    override fun didEnterRegion(p0: Region?) {
        onBeaconScannedInterfaces[p0?.uniqueId]?.didExitRegion(p0)
    }

    override fun didExitRegion(p0: Region?) {
        onBeaconScannedInterfaces[p0?.uniqueId]?.didExitRegion(p0)
    }
}
